/*--------------------------------------------------------------------
       Name: trajtest.sas     Author: Jones BL                                                 
    Created: Feb 2004         Revised:                                                          

The trajtest macro tests hypotheses about model parameters estimated 
in a PROC TRAJ procedure call.
 
Each equation specifies a linear hypothesis to be tested. The multiple 
specifications of a joint hypothesis are separated by commas. 

Variable names correspond to names in the OUTEST= file. 

The trajtest macro performs a Wald chi-square test for the hypothesis 
specified. 

Examples: 

%trajtest('linear1=linear2=linear3')   
%trajtest('linear1=linear2=2')   
%trajtest('linear1=linear2,quadra1=quadra2')   
---------------------------------------------------------------------*/

%macro trajtest(Test1);

%let lngth=%length(&Test1)-2;
%let tmp=%substr(&Test1,2,&lngth);

proc contents noprint data=sscpttz out=_sscptt_(keep=name);
run;

data _xxyxyy_;
  retain icnt 0;
  set _sscptt_;
  if name="_NAME_" | name="_TYPE_" | name="Intercept" | name="YY" 
	then delete; else icnt=icnt+1; 
  call symput('temp'||left(put(icnt,2.)),put(name,32.));
  call symput('VarCnt',left(put(icnt,2.)));
run;

%let sscpvars=;
%do i=1 %to &VarCnt;
   %let sscpvars=%str(&sscpvars &&temp&i);
%end;

ODS OUTPUT TestANOVA=_capxrx_;
ods listing close;
proc reg data=sscpttz;
model yy = &sscpvars / noint;
test &tmp / print; 
run;
ods listing; 

data _capxr1_; set _capxrx_(obs=1);
ChiValue=cinv(1-ProbF,DF);
ProbChi=ProbF; drop Source MS Control Fvalue ProbF Model Test; 
Requested_Test=&Test1;
run;

proc print data=_capxr1_ noobs;
run;

proc datasets nolist;
    delete _xxyxyy_ _sscptt_ _capxrx_ _capxr1_;
run;

%mend trajtest;
